import { classifyNodeGroup } from "./classifyNodeGroup";


export function matchNode(node, filters) {
    const { nameQuery, group } = filters;

    let nameOk = true;
    if (nameQuery) {
        const nodeName = (node.name || "").toLowerCase();
        if (!nodeName.includes(nameQuery.toLowerCase())) {
            nameOk = false;
        }
    }

    let groupOk = true;
    if (group) {
        const nodeGrp = classifyNodeGroup(node);
        if (nodeGrp !== group) {
            groupOk = false;
        }
    }

    
    if (!nameOk || !groupOk) {
        if (node.children && node.children.length > 0) {
            return node.children.some(child => matchNode(child, filters));
        }
        return false;
    }
    return true;
}


export function filterTraceNode(node, filters) {
    if (!matchNode(node, filters)) return null;

    let filteredChildren = [];
    if (node.children && node.children.length > 0) {
        for (const c of node.children) {
            const fc = filterTraceNode(c, filters);
            if (fc) filteredChildren.push(fc);
        }
    }

    return {
        ...node,
        children: filteredChildren
    };
}